@@ -151,7 +151,7 @@ class VCSFileStartHook(hook.Hook):
                             repohdlr.exception(
                                 'error while updating local cache of repository %s',
                                 vcsrepo.eid)
-                    if repo.config['repository-import'] and repo.cw_metainformation()['source']['uri'] == 'system':
+                    if repo.config['repository-import'] and vcsrepo.cw_metainformation()['source']['uri'] == 'system':
                         bridge.import_vcsrepo_content(
                             session, repohdlr, vcsrepo,
                             commitevery=repo.config.get('check-revision-commit-every', 1))
