@@ -85,7 +85,7 @@ class SVNRepository(repo.VCSRepository):
                 # give a change to threads waiting for a pool by freeing it then
                 # reacquiring it
                 session.commit()
-                session.set_pool()
+                session.set_cnxset()
 
     def _file_content(self, path, rev):
         """extract a binary string with the content of the file at `path` for
