@@ -9,7 +9,7 @@ else:
         ('repository-import',
          {'type' : 'yn',
           'default': True,
-          'help': 'Is the repository responsible to automatically import new '
+          'help': 'Is the instance responsible to automatically import new '
                    'revisions from repositories? '
                    'You should say yes unless you don\'t want this behaviour '
                    'or if you use a multiple repositories setup, in which '
@@ -25,7 +25,7 @@ else:
           'level': 2,
           'group': 'vcsfile',
           }),
-        ('check-revision-commmit-every',
+        ('check-revision-commit-every',
          {'type' : 'int',
           'default': 1,
           'help': 'after how much new imported revisions the transaction \
@@ -49,4 +49,15 @@ should be commited (default to 1, e.g. on each revision).',
           'group': 'vcsfile'
           }
          ),
+        ('cache-external-repositories',
+         {'type':'yn',
+          'default': False,
+          'help':'Should repositories from external source have a local cache?'
+          'This is usually not necessary, beside cases where for instance a '
+          'narval bot on the same host as the instance could benefit from them '
+          'to run apycot tests.',
+          'level': 2,
+          'group': 'vcsfile'
+          }
+         ),
         )
