@@ -17,34 +17,58 @@ class RemoveAuthInfoTC(TestCase):
                           'http://***@www.logilab.org/src/cw')
 
 
-class BranchHeadsTC(VCSFileTC):
+def get_parent_revisions(head):
+    return [head.revision] + [vc.revision for vc in head.iter_parent_versions()]
+
+def get_following_revisions(initial):
+    revs = []
+    todo = [initial]
+    while todo:
+        initial = todo.pop(0)
+        if initial.revision in revs:
+            continue
+        revs.append(initial.revision)
+        for child in initial.next_versions():
+            if not child.revision in revs:
+                todo.append(child)
+    return revs
+
+class BranchesTC(VCSFileTC):
     _repo_path = u'testrepohg_branches'
     repo_type = u'mercurial'
 
+    def head(self, file, *args):
+        return self.vcsrepo.versioned_file('', file).branch_head(*args)
+
+    def initial(self, file, *args):
+        return self.vcsrepo.versioned_file('', file).revisions[-1]
+
     def rev(self, file, *args):
-        return self.vcsrepo.versioned_file('', file).branch_head(*args).revision
+        return self.head(file, *args).revision
 
     def test_vcsrm(self):
-        self.grant_write_perm('managers')
-        # XXX outcome depends on method names (=> execution order)
+        self.grant_write_perm(self.session, 'managers', self.vcsrepo.eid)
         vf = self.vcsrepo.versioned_file('', 'README')
         vf.vcs_rm()
         self.commit()
         clear_cache(vf, 'branch_head')
         clear_cache(vf, 'version_content')
         self.assertTrue(vf.deleted_in_branch())
+        # ensure parent_revision has been properly set
         self.assertTrue(vf.head.rev.parent_revision)
-        self.assertEqual(len(vf.head.rev.reverse_at_revision), 3,
+        # ensure at_revision has been properly set, expect 5 files referenced by
+        # the revision
+        self.assertEqual(len(vf.head.rev.reverse_at_revision), 5,
                           vf.head.rev.reverse_at_revision)
 
     def test_branch_head_no_arg(self):
-        self.assertEqual(self.rev('README'), 1)
-        self.assertEqual(self.rev('file.txt'), 4)
+        self.assertEqual(self.rev('README'), 11)
+        self.assertEqual(self.rev('file.txt'), 12)
         self.assertEqual(self.rev('otherfile.txt'), 4)
 
     def test_branch_head_default(self):
-        self.assertEqual(self.rev('README', 'default'), 1)
-        self.assertEqual(self.rev('file.txt', 'default'), 4)
+        self.assertEqual(self.rev('README', 'default'), 11)
+        self.assertEqual(self.rev('file.txt', 'default'), 12)
         self.assertEqual(self.rev('otherfile.txt', 'default'), 4)
 
     def test_branch_head_branch1(self):
@@ -52,6 +76,32 @@ class BranchHeadsTC(VCSFileTC):
         self.assertEqual(self.rev('file.txt', 'branch1'), 2)
         self.assertEqual(self.rev('otherfile.txt', 'branch1'), 3)
 
+    def test_previous_versions(self):
+        self.assertEqual(get_parent_revisions(self.head('README')),
+                         [11, 1, 0])
+        self.assertEqual(get_parent_revisions(self.head('file.txt')),
+                         [12, 10, 4, 2, 0])
+        self.assertEqual(get_parent_revisions(self.head('file.txt', 'branch1')),
+                         [2, 0])
+        self.assertEqual(get_parent_revisions(self.head('otherfile.txt')),
+                         [4, 3])
+        self.assertEqual(get_parent_revisions(self.head('oneagain.txt')),
+                         [9, 7, 6, 5])
+        self.assertEqual(get_parent_revisions(self.head('andagain.txt')),
+                         [9, 8])
+
+    def test_next_versions(self):
+        self.assertEqual(get_following_revisions(self.initial('README')),
+                         [0, 1, 11])
+        self.assertEqual(get_following_revisions(self.initial('file.txt')),
+                         [0, 2, 4, 10, 12])
+        self.assertEqual(get_following_revisions(self.initial('otherfile.txt')),
+                         [3, 4])
+        self.assertEqual(get_following_revisions(self.initial('oneagain.txt')),
+                         [5, 6, 7, 9])
+        self.assertEqual(get_following_revisions(self.initial('andagain.txt')),
+                         [8, 9])
+
 
 class RepositoryTC(CubicWebTC):
     def test_repo_path_security(self):
