@@ -31,7 +31,7 @@ class VCViewsTC(VCSFileTC):
         self.assertEqual(v2.cw_adapt_to('IPrevNext').next_entity(), None)
         v3 = self.execute('Any X WHERE X from_revision R, R revision 3').get_entity(0, 0)
         self.assertIsInstance(v3, entities.DeletedVersionContent)
-        self.failIf(isinstance(v3, entities.VersionContent)) # VersionContent(DeletedVersionContent)
+        self.assertFalse(isinstance(v3, entities.VersionContent)) # VersionContent(DeletedVersionContent)
         self.assertEqual(v3.file.path, "dir1/data.bin.gz")
         self.assertEqual(v3.head.revision, 3)
         self.assertEqual(v3.is_head(), True)
@@ -140,16 +140,17 @@ class VFViewsTC(VCSFileTC):
 class UtilsTC(VCSFileTC):
 
     def test_rql_revision_content(self):
-        rset = self.execute(*entities.rql_revision_content(self.repoeid, 1))
+        repoeid = self.vcsrepo.eid
+        rset = self.execute(*entities.rql_revision_content(repoeid, 1))
         self.assertEqual([(x.file.path, x.revision) for x in rset.entities()],
                           [('toto.txt', 1), ('dir1/data.bin.gz', 1)])
-        rset = self.execute(*entities.rql_revision_content(self.repoeid, 2))
+        rset = self.execute(*entities.rql_revision_content(repoeid, 2))
         self.assertEqual([(x.file.path, x.revision) for x in rset.entities()],
                           [('toto.txt', 2), ('dir1/data.bin.gz', 1)])
-        rset = self.execute(*entities.rql_revision_content(self.repoeid, 3))
+        rset = self.execute(*entities.rql_revision_content(repoeid, 3))
         self.assertEqual([(x.file.path, x.revision) for x in rset.entities()],
                           [('toto.txt', 2), ('dir1/data.bin.gz', 3)])
-        rset = self.execute(*entities.rql_revision_content(self.repoeid, 4))
+        rset = self.execute(*entities.rql_revision_content(repoeid, 4))
         self.assertEqual([(x.file.path, x.revision) for x in rset.entities()],
                           [('toto.txt', 2), ('dir1/tutu.txt', 4)])
 
