@@ -2,7 +2,7 @@
 some information about existing revisions.
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -14,7 +14,8 @@ from logilab.mtconverter import xml_escape
 from logilab.common.decorators import cached
 
 from cubicweb.selectors import (match_form_params, match_kwargs,
-                                is_instance, specified_etype_implements)
+                                is_instance, specified_etype_implements,
+                                match_edited_type)
 from cubicweb.view import EntityView
 from cubicweb.web import (Redirect, RequestError, controller, uicfg, form,
                           formfields as ff, formwidgets as fw)
@@ -63,20 +64,17 @@ class RevisionCreationForm(autoform.AutomaticEntityForm):
         return super(RevisionCreationForm, self).should_display_inline_creation_form(
             rschema, existant, card)
 
-class RevisionIEditControlAdapter(editcontroller.IEditControlAdapter):
-    __select__ = is_instance('Revision')
 
-    def pre_web_edit(self):
-        """callback called by the web editcontroller when an entity will be
-        created/modified, to let a chance to do some entity specific stuff.
-        """
-        if not self.entity.has_eid():
-            try:
-                repoeid = self.entity.linked_to('from_repository', 'subject', remove=False)[0]
-            except IndexError:
-                raise RequestError('missing repository information')
-            self._cw.set_shared_data('vcsrepoeid', repoeid, querydata=True)
+class RevisionEditController(editcontroller.EditController):
+    __select__ = editcontroller.EditController.__select__ & match_edited_type('Revision')
 
+    def _insert_entity(self, etype, eid, rqlquery):
+        try:
+            repoeid = self.linked_to[('from_repository', 'subject')][0]
+        except KeyError:
+            raise RequestError('missing repository information')
+        self._cw.set_shared_data('vcsrepoeid', repoeid, querydata=True)
+        return super(RevisionEditController, self)._insert_entity(etype, eid, rqlquery)
 
 class VCInlinedCreationFormView(autoform.InlineEntityCreationFormView):
     # vfeid needed for the inline-creation of VersionContent
