@@ -14,7 +14,7 @@ from cubicweb.mttransforms import ENGINE
 from cubicweb.selectors import is_instance, score_entity
 from cubicweb.view import EntityView
 from cubicweb.web import uicfg
-from cubicweb.web.views import (ibreadcrumbs, idownloadable,
+from cubicweb.web.views import (ibreadcrumbs, idownloadable, tableview,
                                 baseviews, primary, tabs, navigation)
 
 # primary view tweaks
@@ -91,7 +91,6 @@ class RepositoryInfoTab(tabs.PrimaryTab):
 class RepositoryFilesTab(EntityView):
     __regid__ = 'repositoryfiles_tab'
     __select__ = is_instance('Repository') & score_entity(lambda x: x.import_revision_content)
-
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
         rset = self._cw.execute(
@@ -99,9 +98,14 @@ class RepositoryFilesTab(EntityView):
             'VF modification_date VFMD, VF directory VFD, VF name VFN,'
             'VF from_repository X, X eid %(x)s',
             {'x': entity.eid})
-        self.wview('table', rset, 'noresult',
-                   paginate=True, displayfilter=True,
-                   displaycols=[0, 1], cellvids={0: 'incontext'})
+        self.wview('vcsfile.table.files', rset, 'noresult')
+
+class VersionedFilesTable(tableview.RsetTableView):
+    __regid__ = 'vcsfile.table.files'
+    __select__ = is_instance('VersionedFile')
+    displaycols = [0, 1]
+    cellvids = {0: 'incontext'}
+    layout_args = {'display_filter': 'top'}
 
 
 class RepositoryHistoryTab(EntityView):
@@ -115,8 +119,13 @@ class RepositoryHistoryTab(EntityView):
             'R branch RB, R author RA, R description RD, R creation_date RCD,'
             'R revision RN, R changeset RCS, R from_repository X, X eid %(x)s',
             {'x': entity.eid})
-        self.wview('table', rset, 'noresult',
-                   paginate=True, displayfilter=True, displaycols=range(5))
+        self.wview('vcsfile.table.revisions', rset, 'noresult')
+
+class RevisionsTable(tableview.RsetTableView):
+    __regid__ = 'vcsfile.table.revisions'
+    __select__ = is_instance('Revision')
+    displaycols = range(5)
+    layout_args = {'display_filter': 'top'}
 
 
 class RepositoryCheckOutInstructionsView(EntityView):
@@ -246,10 +255,12 @@ class VFPrimaryView(primary.PrimaryView):
             'R branch RB, R author RA, R description RD, R creation_date RC,'
             'VF eid %(x)s',
             {'x': entity.eid})
-        self.wview('table', rset, 'noresult',
-                   paginate=True, displayfilter=True,
-                   displaycols=range(5),
-                   cellvids={0: 'revision'})
+        self.wview('vcsfile.table.revisions', rset, 'noresult')
+
+
+class VersionedFileRevisionsTable(RevisionsTable):
+    __select__ = is_instance('DeletedVersionContent', 'VersionContent')
+    cellvids = {0: 'revision'}
 
 
 class RevisionPrimaryView(primary.PrimaryView):
